@@ -295,13 +295,6 @@ exchange_folder_cache_xfer (CamelExchangeFolder *folder_source,
 	}
 }
 
-static void
-free_index_and_mid (gpointer thread_index, gpointer message_id, gpointer d)
-{
-	g_free (thread_index);
-	g_free (message_id);
-}
-
 static void
 exchange_folder_dispose (GObject *object)
 {
@@ -321,12 +314,8 @@ exchange_folder_finalize (GObject *object)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (object);
 
-	if (exch->thread_index_to_message_id) {
-		g_hash_table_foreach (
-			exch->thread_index_to_message_id,
-			free_index_and_mid, NULL);
+	if (exch->thread_index_to_message_id)
 		g_hash_table_destroy (exch->thread_index_to_message_id);
-	}
 
 	g_free (exch->source);
 
@@ -880,8 +869,6 @@ camel_exchange_folder_remove_message (CamelExchangeFolder *exch,
 						  einfo->thread_index,
 						  &key, &value)) {
 			g_hash_table_remove (exch->thread_index_to_message_id, key);
-			g_free (key);
-			g_free (value);
 		}
 	}
 
@@ -1091,7 +1078,7 @@ camel_exchange_folder_construct (CamelFolder *folder,
 	camel_object_state_read (CAMEL_OBJECT (folder));
 
 	exch->thread_index_to_message_id =
-		g_hash_table_new (g_str_hash, g_str_equal);
+		g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
 	len = camel_folder_summary_count (folder->summary);
 	for (i = 0; i < len; i++) {
@@ -1121,7 +1108,7 @@ camel_exchange_folder_construct (CamelFolder *folder,
 		g_ptr_array_set_size (hrefs, summary->len);
 
 		for (i = 0; i < summary->len; i++) {
-			uids->pdata[i] = g_strdup(summary->pdata[i]);
+			uids->pdata[i] = summary->pdata[i];
 			info = camel_folder_summary_uid (folder->summary, uids->pdata[i]);
 			flags->data[i] = ((CamelMessageInfoBase *)info)->flags & CAMEL_EXCHANGE_SERVER_FLAGS;
 			hrefs->pdata[i] = ((CamelExchangeMessageInfo *)info)->href;
