@@ -23,77 +23,32 @@
 #include <config.h>
 #endif
 
+#include <string.h>
 #include <glib/gi18n-lib.h>
 
 #include "camel-exchange-transport.h"
 #include "camel-exchange-utils.h"
 
-#include <camel/camel-data-wrapper.h>
-#include <camel/camel-exception.h>
-#include <camel/camel-mime-filter-crlf.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-session.h>
-#include <camel/camel-stream-filter.h>
-#include <camel/camel-stream-mem.h>
-
-#include <string.h>
-
-static gboolean exchange_send_to (CamelTransport *transport,
-				  CamelMimeMessage *message,
-				  CamelAddress *from,
-				  CamelAddress *recipients,
-				  CamelException *ex);
-
-static void
-camel_exchange_transport_class_init (CamelExchangeTransportClass *camel_exchange_transport_class)
-{
-	CamelTransportClass *camel_transport_class =
-		CAMEL_TRANSPORT_CLASS (camel_exchange_transport_class);
-
-	/* virtual method overload */
-	camel_transport_class->send_to = exchange_send_to;
-}
-
-static void
-camel_exchange_transport_init (CamelTransport *transport)
-{
-}
-
-CamelType
-camel_exchange_transport_get_type (void)
-{
-	static CamelType camel_exchange_transport_type = CAMEL_INVALID_TYPE;
-
-	if (camel_exchange_transport_type == CAMEL_INVALID_TYPE) {
-		camel_exchange_transport_type =
-			camel_type_register (CAMEL_TRANSPORT_TYPE,
-					     "CamelExchangeTransport",
-					     sizeof (CamelExchangeTransport),
-					     sizeof (CamelExchangeTransportClass),
-					     (CamelObjectClassInitFunc) camel_exchange_transport_class_init,
-					     NULL,
-					     (CamelObjectInitFunc) camel_exchange_transport_init,
-					     NULL);
-	}
-
-	return camel_exchange_transport_type;
-}
+G_DEFINE_TYPE (CamelExchangeTransport, camel_exchange_transport, CAMEL_TYPE_TRANSPORT)
 
 static gboolean
-exchange_send_to (CamelTransport *transport, CamelMimeMessage *message,
-		  CamelAddress *from, CamelAddress *recipients,
-		  CamelException *ex)
+exchange_transport_send_to (CamelTransport *transport,
+                            CamelMimeMessage *message,
+                            CamelAddress *from,
+                            CamelAddress *recipients,
+                            CamelException *ex)
 {
 	CamelService *service = CAMEL_SERVICE (transport);
 	CamelStore *store = NULL;
 	gchar *url_string;
-	const CamelInternetAddress *cia;
+	CamelInternetAddress *cia;
 	const gchar *addr;
 	GPtrArray *recipients_array;
 	gboolean success;
 	CamelStream *stream;
-	CamelStreamFilter *filtered_stream;
+	CamelStream *filtered_stream;
 	CamelMimeFilter *crlffilter;
+	GByteArray *byte_array;
 	struct _camel_header_raw *header;
 	GSList *h, *bcc = NULL;
 	gint len, i;
@@ -131,11 +86,14 @@ exchange_send_to (CamelTransport *transport, CamelMimeMessage *message,
 		return FALSE;
 	}
 
-	stream = camel_stream_mem_new ();
+	byte_array = g_byte_array_new ();
+	stream = camel_stream_mem_new_with_byte_array (byte_array);
 	crlffilter = camel_mime_filter_crlf_new (CAMEL_MIME_FILTER_CRLF_ENCODE, CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
-	filtered_stream = camel_stream_filter_new_with_stream (stream);
-	camel_stream_filter_add (filtered_stream, CAMEL_MIME_FILTER (crlffilter));
-	camel_object_unref (CAMEL_OBJECT (crlffilter));
+	filtered_stream = camel_stream_filter_new (stream);
+	camel_stream_filter_add (
+		CAMEL_STREAM_FILTER (filtered_stream),
+		CAMEL_MIME_FILTER (crlffilter));
+	g_object_unref (CAMEL_OBJECT (crlffilter));
 
 	/* Gross hack copied from camel-smtp-transport. ugh. FIXME */
 	/* copy and remove the bcc headers */
@@ -151,7 +109,7 @@ exchange_send_to (CamelTransport *transport, CamelMimeMessage *message,
 	camel_data_wrapper_write_to_stream (CAMEL_DATA_WRAPPER (message),
 					    CAMEL_STREAM (filtered_stream));
 	camel_stream_flush (CAMEL_STREAM (filtered_stream));
-	camel_object_unref (CAMEL_OBJECT (filtered_stream));
+	g_object_unref (CAMEL_OBJECT (filtered_stream));
 
 	/* add the bcc headers back */
 	if (bcc) {
@@ -164,12 +122,27 @@ exchange_send_to (CamelTransport *transport, CamelMimeMessage *message,
 		g_slist_free (bcc);
 	}
 
-	success = camel_exchange_utils_send_message (CAMEL_SERVICE (transport), addr, recipients_array, CAMEL_STREAM_MEM (stream)->buffer, ex);
+	success = camel_exchange_utils_send_message (CAMEL_SERVICE (transport), addr, recipients_array, byte_array, ex);
 
 	g_ptr_array_free (recipients_array, TRUE);
-	camel_object_unref (CAMEL_OBJECT (stream));
+	g_object_unref (stream);
 
 	if (store)
-		camel_object_unref (CAMEL_OBJECT (store));
+		g_object_unref (CAMEL_OBJECT (store));
 	return success;
 }
+
+static void
+camel_exchange_transport_class_init (CamelExchangeTransportClass *class)
+{
+	CamelTransportClass *transport_class;
+
+	transport_class = CAMEL_TRANSPORT_CLASS (class);
+	transport_class->send_to = exchange_transport_send_to;
+}
+
+static void
+camel_exchange_transport_init (CamelExchangeTransport *transport)
+{
+}
+
